sheep Package
=============

:mod:`client` Module
--------------------

.. automodule:: sheepdog.sheep.client
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`job_file` Module
----------------------

.. automodule:: sheepdog.sheep.job_file
    :members:
    :undoc-members:
    :show-inheritance:

